@@ -203,7 +203,7 @@ def FC_AConnect(output_size,Wstd=0,Bstd=0,isBin="no",pool=None,Slice=1,d_type=tf
 
 		#THis is only for saving purposes. Does not affect the layer performance.	
 		def get_config(self):
-			config = super(AConnect, self).get_config()
+			config = super(FC_AConnect, self).get_config()
 			config.update({
 				'output_size': self.output_size,
 				'Wstd': self.Wstd,
@@ -295,10 +295,10 @@ def Conv_AConnect(filters,kernel_size,strides=1,padding="VALID",Wstd=0,Bstd=0,po
 	-Slice: Optional parameter. Used to divide the batch into 2,4 or 8 minibatches of size batch/N.
 	-d_type: Type of the parameters that the layers will create. Supports fp16, fp32 and fp64 
 	"""
-	class ConvAConnect(tf.keras.layers.Layer):
+	class Conv_AConnect(tf.keras.layers.Layer):
 		def __init__(self,filters,kernel_size,strides=1,padding="VALID",Wstd=0,Bstd=0,pool=None,isBin='no',Op=1
 		,Slice=1,d_type=tf.dtypes.float32,weights_regularizer=None,bias_regularizer=None,**kwargs):
-			super(ConvAConnect, self).__init__()
+			super(Conv_AConnect, self).__init__()
 			self.filters = filters
 			self.kernel_size = kernel_size
 			self.Wstd = Wstd
@@ -345,7 +345,7 @@ def Conv_AConnect(filters,kernel_size,strides=1,padding="VALID",Wstd=0,Bstd=0,po
 			else:
 				self.Werr = tf.constant(1,dtype=self.d_type) #We need to define the number 1 as a float32.
 				self.Berr = tf.constant(1,dtype=self.d_type)
-			super(ConvAConnect, self).build(input_shape)
+			super(Conv_AConnect, self).build(input_shape)
 		def call(self,X,training):
 			self.X = tf.cast(X, dtype=self.d_type)       
 			self.batch_size = tf.shape(self.X)[0]
@@ -534,7 +534,7 @@ def Conv_AConnect(filters,kernel_size,strides=1,padding="VALID",Wstd=0,Bstd=0,po
 			if self.pool is not None and not isinstance(self.pool, int):
 				raise TypeError('pool must be a integer. ' 'Found %s' %(type(self.pool),))             
 		def get_config(self):
-			config = super(ConvAConnect, self).get_config()
+			config = super(Conv_AConnect, self).get_config()
 			config.update({
 				'filters': self.filters,
 				'kernel_size': self.kernel_size,
@@ -585,5 +585,5 @@ def Conv_AConnect(filters,kernel_size,strides=1,padding="VALID",Wstd=0,Bstd=0,po
 		if padding == "VALID":
 		    return tf.reshape(Z, [tf.floor(tf.cast((H-fh)/strides,dtype=tf.float16))+1, tf.floor(tf.cast((W-fw)/strides,dtype=tf.float16))+1, batch_size, channels, out_channels])
 		#return out              			
-	return ConvAConnect(filters,kernel_size,strides=strides,padding=padding,Wstd=Wstd,Bstd=Bstd,pool=pool,isBin=isBin,Op=Op
+	return Conv_AConnect(filters,kernel_size,strides=strides,padding=padding,Wstd=Wstd,Bstd=Bstd,pool=pool,isBin=isBin,Op=Op
 			,Slice=Slice,d_type=d_type,weights_regularizer=weights_regularizer,bias_regularizer=bias_regularizer)		
